@@ -40,7 +40,7 @@ class KCubeWidget : public QFrame
          
 public:
    /** constructs a new KCubeWidget*/
-   explicit KCubeWidget (QWidget * parent = 0);
+   explicit KCubeWidget (QWidget * parent = nullptr);
    virtual ~KCubeWidget();
 
    Player owner() { return m_owner; }
@@ -79,10 +79,10 @@ signals:
 
 protected:
    /** checks, if mouseclick was inside this cube*/
-   virtual void mouseReleaseEvent(QMouseEvent*);
+   void mouseReleaseEvent(QMouseEvent*) override;
 
    /** refreshes the contents of the Cube */
-   virtual void paintEvent(QPaintEvent*);
+   void paintEvent(QPaintEvent*) override;
 
 private:
    int m_row;
